@@ -19,6 +19,8 @@
 #if __cplusplus >= 201703L
 #include <cstddef>
 #else
+#ifndef STD_BYTE_DEFINED
+#define STD_BYTE_DEFINED
 namespace std {
 #ifdef _CRAYC
 struct byte {
@@ -31,6 +33,7 @@ enum class byte : unsigned char
 #endif
 }  // namespace std
 #endif
+#endif
 
 //------------------------------------------------------------------------------------------------------
 
@@ -86,6 +89,7 @@ public:
     DataType(const std::string&);
     DataType(long);
     DataType(const DataType&);
+    DataType& operator=(const DataType&);
     std::string str() const { return kind_to_str(kind_); }
     kind_t kind() const { return kind_; }
     size_t size() const { return (kind_ == KIND_UINT64) ? 8 : std::abs(kind_); }
@@ -361,6 +365,11 @@ inline bool DataType::kind_valid(kind_t kind) {
 
 inline DataType::DataType(const DataType& other): kind_(other.kind_) {}
 
+inline DataType& DataType::operator=(const DataType& other) {
+    kind_ = other.kind_;
+    return *this;
+}
+
 inline DataType::DataType(const std::string& datatype): kind_(str_to_kind(datatype)) {}
 
 inline DataType::DataType(long kind): kind_(kind) {}
