@@ -13,6 +13,7 @@
 
 #include "atlas/array/ArrayView.h"
 #include "atlas/array/helpers/ArrayAssigner.h"
+#include "atlas/array/helpers/ArrayCopier.h"
 #include "atlas/array/helpers/ArrayWriter.h"
 
 //------------------------------------------------------------------------------------------------------
@@ -41,6 +42,14 @@ ENABLE_IF_NON_CONST void ArrayView<Value, Rank>::assign(const std::initializer_l
 
 //------------------------------------------------------------------------------------------------------
 
+
+template <typename Value, int Rank>
+ENABLE_IF_NON_CONST void ArrayView<Value, Rank>::assign(const ArrayView& other) {
+    helpers::array_copier<Value, Rank>::apply(other, *this);
+}
+
+//------------------------------------------------------------------------------------------------------
+
 template <typename Value, int Rank>
 void ArrayView<Value, Rank>::dump(std::ostream& os) const {
     os << "size: " << size() << " , values: ";
@@ -58,25 +67,29 @@ void ArrayView<Value, Rank>::dump(std::ostream& os) const {
 // Explicit instantiation
 namespace atlas {
 namespace array {
-#define EXPLICIT_TEMPLATE_INSTANTIATION(Rank)                                                         \
-    template class ArrayView<int, Rank>;                                                              \
-    template class ArrayView<const int, Rank>;                                                        \
-    template class ArrayView<long, Rank>;                                                             \
-    template class ArrayView<const long, Rank>;                                                       \
-    template class ArrayView<long unsigned, Rank>;                                                    \
-    template class ArrayView<const long unsigned, Rank>;                                              \
-    template class ArrayView<float, Rank>;                                                            \
-    template class ArrayView<const float, Rank>;                                                      \
-    template class ArrayView<double, Rank>;                                                           \
-    template class ArrayView<const double, Rank>;                                                     \
-    template void ArrayView<int, Rank>::assign<true, nullptr>(int const&);                            \
-    template void ArrayView<long, Rank>::assign<true, nullptr>(long const&);                          \
-    template void ArrayView<float, Rank>::assign<true, nullptr>(float const&);                        \
-    template void ArrayView<double, Rank>::assign<true, nullptr>(double const&);                      \
-    template void ArrayView<int, Rank>::assign<true, nullptr>(std::initializer_list<int> const&);     \
-    template void ArrayView<long, Rank>::assign<true, nullptr>(std::initializer_list<long> const&);   \
-    template void ArrayView<float, Rank>::assign<true, nullptr>(std::initializer_list<float> const&); \
-    template void ArrayView<double, Rank>::assign<true, nullptr>(std::initializer_list<double> const&);
+#define EXPLICIT_TEMPLATE_INSTANTIATION(Rank)                                                           \
+    template class ArrayView<int, Rank>;                                                                \
+    template class ArrayView<const int, Rank>;                                                          \
+    template class ArrayView<long, Rank>;                                                               \
+    template class ArrayView<const long, Rank>;                                                         \
+    template class ArrayView<long unsigned, Rank>;                                                      \
+    template class ArrayView<const long unsigned, Rank>;                                                \
+    template class ArrayView<float, Rank>;                                                              \
+    template class ArrayView<const float, Rank>;                                                        \
+    template class ArrayView<double, Rank>;                                                             \
+    template class ArrayView<const double, Rank>;                                                       \
+    template void ArrayView<int, Rank>::assign<true, nullptr>(int const&);                              \
+    template void ArrayView<long, Rank>::assign<true, nullptr>(long const&);                            \
+    template void ArrayView<float, Rank>::assign<true, nullptr>(float const&);                          \
+    template void ArrayView<double, Rank>::assign<true, nullptr>(double const&);                        \
+    template void ArrayView<int, Rank>::assign<true, nullptr>(std::initializer_list<int> const&);       \
+    template void ArrayView<long, Rank>::assign<true, nullptr>(std::initializer_list<long> const&);     \
+    template void ArrayView<float, Rank>::assign<true, nullptr>(std::initializer_list<float> const&);   \
+    template void ArrayView<double, Rank>::assign<true, nullptr>(std::initializer_list<double> const&); \
+    template void ArrayView<int, Rank>::assign<true, nullptr>(ArrayView<int, Rank> const&);             \
+    template void ArrayView<long, Rank>::assign<true, nullptr>(ArrayView<long, Rank> const&);           \
+    template void ArrayView<float, Rank>::assign<true, nullptr>(ArrayView<float, Rank> const&);         \
+    template void ArrayView<double, Rank>::assign<true, nullptr>(ArrayView<double, Rank> const&);
 
 // For each NDims in [1..9]
 EXPLICIT_TEMPLATE_INSTANTIATION(1)
