@@ -20,6 +20,7 @@
 #include "atlas/mesh/HybridElements.h"
 #include "atlas/mesh/IsGhostNode.h"
 #include "atlas/mesh/Mesh.h"
+#include "atlas/mesh/actions/Build2DCellCentres.h"
 #include "atlas/mesh/actions/BuildHalo.h"
 #include "atlas/mesh/actions/BuildParallelFields.h"
 #include "atlas/mesh/actions/BuildPeriodicBoundaries.h"
@@ -564,6 +565,9 @@ const parallel::Checksum& CellColumns::checksum() const {
 }
 
 Field CellColumns::lonlat() const {
+    if (!mesh_.cells().has_field("lonlat")) {
+        mesh::actions::Build2DCellCentres("lonlat")(const_cast<Mesh&>(mesh_));
+    }
     return mesh_.cells().field("lonlat");
 }
 
@@ -819,30 +823,6 @@ const parallel::HaloExchange& CellColumns::halo_exchange() const {
     return functionspace_->halo_exchange();
 }
 
-void CellColumns::gather(const FieldSet& local, FieldSet& global) const {
-    functionspace_->gather(local, global);
-}
-
-void CellColumns::gather(const Field& local, Field& global) const {
-    functionspace_->gather(local, global);
-}
-
-const parallel::GatherScatter& CellColumns::gather() const {
-    return functionspace_->gather();
-}
-
-void CellColumns::scatter(const FieldSet& global, FieldSet& local) const {
-    functionspace_->scatter(global, local);
-}
-
-void CellColumns::scatter(const Field& global, Field& local) const {
-    functionspace_->scatter(global, local);
-}
-
-const parallel::GatherScatter& CellColumns::scatter() const {
-    return functionspace_->scatter();
-}
-
 std::string CellColumns::checksum(const FieldSet& fieldset) const {
     return functionspace_->checksum(fieldset);
 }
