@@ -537,8 +537,10 @@ void NodeColumns::scatter(const FieldSet& global_fieldset, FieldSet& local_field
             throw_Exception("datatype not supported", Here());
         }
 
+        auto name = loc.name();
         glb.metadata().broadcast(loc.metadata(), root);
         loc.metadata().set("global", false);
+        loc.metadata().set("name", name);
     }
 }
 
@@ -684,30 +686,6 @@ const parallel::HaloExchange& NodeColumns::halo_exchange() const {
     return functionspace_->halo_exchange();
 }
 
-void NodeColumns::gather(const FieldSet& local, FieldSet& global) const {
-    functionspace_->gather(local, global);
-}
-
-void NodeColumns::gather(const Field& local, Field& global) const {
-    functionspace_->gather(local, global);
-}
-
-const parallel::GatherScatter& NodeColumns::gather() const {
-    return functionspace_->gather();
-}
-
-void NodeColumns::scatter(const FieldSet& global, FieldSet& local) const {
-    functionspace_->scatter(global, local);
-}
-
-void NodeColumns::scatter(const Field& global, Field& local) const {
-    functionspace_->scatter(global, local);
-}
-
-const parallel::GatherScatter& NodeColumns::scatter() const {
-    return functionspace_->scatter();
-}
-
 std::string NodeColumns::checksum(const FieldSet& fieldset) const {
     return functionspace_->checksum(fieldset);
 }
