@@ -90,7 +90,7 @@ public:
         return array::make_view<const int, 1>(trans_->nasm0, array::make_shape(trans_->nsmax + 1));
     }
 
-    std::string distribution() const { return "trans"; }
+    std::string distribution() const { return "ectrans"; }
     operator ::Trans_t*() const { return trans_.get(); }
     std::shared_ptr<::Trans_t> trans_;
 };
@@ -467,22 +467,6 @@ int Spectral::truncation() const {
     return functionspace_->truncation();
 }
 
-void Spectral::gather(const FieldSet& local_fieldset, FieldSet& global_fieldset) const {
-    functionspace_->gather(local_fieldset, global_fieldset);
-}
-
-void Spectral::gather(const Field& local, Field& global) const {
-    functionspace_->gather(local, global);
-}
-
-void Spectral::scatter(const FieldSet& global_fieldset, FieldSet& local_fieldset) const {
-    functionspace_->scatter(global_fieldset, local_fieldset);
-}
-
-void Spectral::scatter(const Field& global, Field& local) const {
-    functionspace_->scatter(global, local);
-}
-
 std::string Spectral::checksum(const FieldSet& fieldset) const {
     return functionspace_->checksum(fieldset);
 }
