@@ -79,20 +79,20 @@ Interpolation::Interpolation(const Interpolation::Config& config, const Function
     }
 }
 
-void Interpolation::execute(const FieldSet& source, FieldSet& target) const {
-    get()->execute(source, target);
+Interpolation::Metadata Interpolation::execute(const FieldSet& source, FieldSet& target) const {
+    return get()->execute(source, target);
 }
 
-void Interpolation::execute(const Field& source, Field& target) const {
-    get()->execute(source, target);
+Interpolation::Metadata Interpolation::execute(const Field& source, Field& target) const {
+    return get()->execute(source, target);
 }
 
-void Interpolation::execute_adjoint(FieldSet& source, const FieldSet& target) const {
-    get()->execute_adjoint(source, target);
+Interpolation::Metadata Interpolation::execute_adjoint(FieldSet& source, const FieldSet& target) const {
+    return get()->execute_adjoint(source, target);
 }
 
-void Interpolation::execute_adjoint(Field& source, const Field& target) const {
-    get()->execute_adjoint(source, target);
+Interpolation::Metadata Interpolation::execute_adjoint(Field& source, const Field& target) const {
+    return get()->execute_adjoint(source, target);
 }
 
 void Interpolation::print(std::ostream& out) const {
@@ -177,6 +177,20 @@ void atlas__Interpolation__execute_fieldset(Interpolation::Implementation* This,
     This->execute(FieldSet(source), t);
 }
 
+
+void atlas__Interpolation__execute_adjoint_field(Interpolation::Implementation* This, field::FieldImpl* source,
+                                                 const field::FieldImpl* target) {
+    Field s(source);
+    This->execute_adjoint(s, Field(target));
+}
+
+void atlas__Interpolation__execute_adjoint_fieldset(Interpolation::Implementation* This, field::FieldSetImpl* source,
+                                                    const field::FieldSetImpl* target) {
+    FieldSet s(source);
+    This->execute_adjoint(s, FieldSet(target));
+}
+
+
 }  // extern "C"
 
 }  // namespace atlas
