@@ -102,7 +102,7 @@ void NearestNeighbour::do_setup(const FunctionSpace& source, const FunctionSpace
 
     // fill sparse matrix and return
     Matrix A(out_npts, inp_npts, weights_triplets);
-    matrix_shared_->swap(A);
+    setMatrix(A);
 }
 
 }  // namespace method
