@@ -56,9 +56,9 @@ private:
 
     virtual void do_setup(const FunctionSpace& source, const FieldSet& target) override;
 
-    virtual void do_execute(const Field& src, Field& tgt) const override;
+    virtual void do_execute(const Field& src, Field& tgt, Metadata&) const override;
 
-    virtual void do_execute(const FieldSet& src, FieldSet& tgt) const override;
+    virtual void do_execute(const FieldSet& src, FieldSet& tgt, Metadata&) const override;
 
     template <typename Value, int Rank>
     void execute_impl(const Kernel& kernel, const FieldSet& src, FieldSet& tgt) const;
