@@ -89,6 +89,7 @@ public:
 protected:
     virtual const void* addr() const override;
 
+    bool initialized_{false};
     bool debug_{false};
     bool info_{true};
     bool warning_{true};
@@ -104,6 +105,7 @@ protected:
 private:
     std::vector<eckit::system::Plugin*> plugins_;
     std::vector<std::string> data_paths_;
+    size_t atlas_io_trace_hook_;
 };
 
 using Atlas = Library;
