@@ -19,7 +19,7 @@ namespace detail {
 class CubedSphereEquiDistProjection final : public CubedSphereProjectionBase {
 public:
     // constructor
-    CubedSphereEquiDistProjection( const eckit::Parametrisation& );
+    CubedSphereEquiDistProjection(const eckit::Parametrisation&);
 
     virtual ~CubedSphereEquiDistProjection() {}
 
@@ -27,15 +27,27 @@ public:
     static std::string static_type() { return "cubedsphere_equidistant"; }
     std::string type() const override { return static_type(); }
 
-    // projection and inverse projection
-    void xy2lonlat( double crd[] ) const override;
-    void lonlat2xy( double crd[] ) const override;
+    /// @brief Convert (x, y) coordinate to (alpha, beta) on tile t.
+    void xy2alphabeta(double crd[], idx_t t) const override;
 
-    Jacobian jacobian( const PointLonLat& ) const override;
+    /// @brief Convert (alpha, beta) coordinate to (x, y) on tile t.
+    void alphabeta2xy(double crd[], idx_t t) const override;
+
+    /// @brief Jacobian of (alpha, beta) with respect to (lon, lat) on tile t
+    Jacobian alphabetaJacobian(const PointLonLat& lonlat, idx_t t) const override;
+
+    /// @brief Jacobian of (x, y) with respect to (lon, lat) on tile t
+    Jacobian jacobian(const PointLonLat& lonlat, idx_t t) const override;
+
+    // projection and inverse projection
+    void xy2lonlat(double crd[]) const override;
+    void lonlat2xy(double crd[]) const override;
+
+    Jacobian jacobian(const PointLonLat&) const override;
 
     bool strictlyRegional() const override { return false; }
-    RectangularLonLatDomain lonlatBoundingBox( const Domain& domain ) const override {
-        return ProjectionImpl::lonlatBoundingBox( domain );
+    RectangularLonLatDomain lonlatBoundingBox(const Domain& domain) const override {
+        return ProjectionImpl::lonlatBoundingBox(domain);
     }
 
     // specification
@@ -43,7 +55,7 @@ public:
 
     std::string units() const override { return "degrees"; }
 
-    void hash( eckit::Hash& ) const override;
+    void hash(eckit::Hash&) const override;
 };
 
 }  // namespace detail
